PALM-meteo: palmmeteo.plugins Namespace Reference

PALM-meteo

Classes | Functions | Variables
palmmeteo.plugins Namespace Reference

## Classes
class | HInterpPluginMixin
class | ImportPluginMixin
class | Plugin
class | PluginMeta
class | SetupPluginMixin
class | VInterpPluginMixin
class | WritePluginMixin

## Functions
def | eventhandler (event)
def | plugin_factory (plugin, *args, **kwargs)

## Variables
dictionary | event_hooks
list | plugins = []

## Function Documentation

## ◆ eventhandler()

def palmmeteo.plugins.eventhandler | ( |  | event | ) |

    Decorator function to register method as an event handler.

## ◆ plugin_factory()

def palmmeteo.plugins.plugin_factory | ( |  | plugin,
|  | * | args,
|  | ** | kwargs
| ) |  |

## Variable Documentation

## ◆ event_hooks

dictionary palmmeteo.plugins.event_hooks

Initial value:
1= {
2}

## ◆ plugins

list palmmeteo.plugins.plugins = []